@@ -1,22 +1,33 @@
 """Activate, get and deactivate translations."""
+from __future__ import annotations
+
 import gettext as gettext_module
 import os.path
-import warnings
 from threading import local
 
-__all__ = ["activate", "deactivate", "gettext", "ngettext", "thousands_separator"]
+__all__ = ["activate", "deactivate", "decimal_separator", "thousands_separator"]
 
-_TRANSLATIONS = {None: gettext_module.NullTranslations()}
+_TRANSLATIONS: dict[str | None, gettext_module.NullTranslations] = {
+    None: gettext_module.NullTranslations()
+}
 _CURRENT = local()
 
 
 # Mapping of locale to thousands separator
 _THOUSANDS_SEPARATOR = {
+    "de_DE": ".",
     "fr_FR": " ",
+    "pt_BR": ".",
+}
+
+# Mapping of locale to decimal separator
+_DECIMAL_SEPARATOR = {
+    "de_DE": ",",
+    "pt_BR": ",",
 }
 
 
-def _get_default_locale_path():
+def _get_default_locale_path() -> str | None:
     try:
         if __file__ is None:
             return None
@@ -25,14 +36,14 @@ def _get_default_locale_path():
         return None
 
 
-def get_translation():
+def get_translation() -> gettext_module.NullTranslations:
     try:
         return _TRANSLATIONS[_CURRENT.locale]
     except (AttributeError, KeyError):
         return _TRANSLATIONS[None]
 
 
-def activate(locale, path=None):
+def activate(locale: str, path: str | None = None) -> gettext_module.NullTranslations:
     """Activate internationalisation.
 
     Set `locale` as current locale. Search for locale in directory `path`.
@@ -51,10 +62,11 @@ def activate(locale, path=None):
         path = _get_default_locale_path()
 
     if path is None:
-        raise Exception(
+        msg = (
             "Humanize cannot determinate the default location of the 'locale' folder. "
             "You need to pass the path explicitly."
         )
+        raise Exception(msg)
     if locale not in _TRANSLATIONS:
         translation = gettext_module.translation("humanize", path, [locale])
         _TRANSLATIONS[locale] = translation
@@ -62,12 +74,12 @@ def activate(locale, path=None):
     return _TRANSLATIONS[locale]
 
 
-def deactivate():
+def deactivate() -> None:
     """Deactivate internationalisation."""
     _CURRENT.locale = None
 
 
-def _gettext(message):
+def _gettext(message: str) -> str:
     """Get translation.
 
     Args:
@@ -79,27 +91,7 @@ def _gettext(message):
     return get_translation().gettext(message)
 
 
-def gettext(message):
-    """Get translation.
-
-    Args:
-        message (str): Text to translate.
-
-    Returns:
-        str: Translated text.
-
-    WARNING: This function has been deprecated. It is still available as the private
-    member `_gettext`.
-    """
-    warnings.warn(
-        "`gettext` has been deprecated. "
-        "It is still available as the private member `_gettext`.",
-        DeprecationWarning,
-    )
-    return _gettext(message)
-
-
-def _pgettext(msgctxt, message):
+def _pgettext(msgctxt: str, message: str) -> str:
     """Fetches a particular translation.
 
     It works with `msgctxt` .po modifiers and allows duplicate keys with different
@@ -124,37 +116,13 @@ def _pgettext(msgctxt, message):
         return message if translation == key else translation
 
 
-def pgettext(msgctxt, message):
-    """Fetches a particular translation.
-
-    It works with `msgctxt` .po modifiers and allows duplicate keys with different
-    translations.
-
-    Args:
-        msgctxt (str): Context of the translation.
-        message (str): Text to translate.
-
-    Returns:
-        str: Translated text.
-
-    WARNING: This function has been deprecated. It is still available as the private
-    member `_pgettext`.
-    """
-    warnings.warn(
-        "`pgettext` has been deprecated. "
-        "It is still available as the private member `_pgettext`.",
-        DeprecationWarning,
-    )
-    return _pgettext(msgctxt, message)
-
-
-def _ngettext(message, plural, num):
+def _ngettext(message: str, plural: str, num: int) -> str:
     """Plural version of _gettext.
 
     Args:
         message (str): Singular text to translate.
         plural (str): Plural text to translate.
-        num (str): The number (e.g. item count) to determine translation for the
+        num (int): The number (e.g. item count) to determine translation for the
             respective grammatical number.
 
     Returns:
@@ -163,30 +131,7 @@ def _ngettext(message, plural, num):
     return get_translation().ngettext(message, plural, num)
 
 
-def ngettext(msgctxt, message):
-    """Plural version of gettext.
-
-    Args:
-        message (str): Singular text to translate.
-        plural (str): Plural text to translate.
-        num (str): The number (e.g. item count) to determine translation for the
-            respective grammatical number.
-
-    Returns:
-        str: Translated text.
-
-    WARNING: This function has been deprecated. It is still available as the private
-    member `_ngettext`.
-    """
-    warnings.warn(
-        "`ngettext` has been deprecated. "
-        "It is still available as the private member `_ngettext`.",
-        DeprecationWarning,
-    )
-    return _ngettext(msgctxt, message)
-
-
-def _gettext_noop(message):
+def _gettext_noop(message: str) -> str:
     """Mark a string as a translation string without translating it.
 
     Example usage:
@@ -205,34 +150,7 @@ def _gettext_noop(message):
     return message
 
 
-def gettext_noop(message):
-    """Mark a string as a translation string without translating it.
-
-    Example usage:
-    ```python
-    CONSTANTS = [_gettext_noop('first'), _gettext_noop('second')]
-    def num_name(n):
-        return _gettext(CONSTANTS[n])
-    ```
-
-    Args:
-        message (str): Text to translate in the future.
-
-    Returns:
-        str: Original text, unchanged.
-
-    WARNING: This function has been deprecated. It is still available as the private
-    member `_gettext_noop`.
-    """
-    warnings.warn(
-        "`gettext_noop` has been deprecated. "
-        "It is still available as the private member `_gettext_noop`.",
-        DeprecationWarning,
-    )
-    return _gettext_noop(message)
-
-
-def _ngettext_noop(singular, plural):
+def _ngettext_noop(singular: str, plural: str) -> tuple[str, str]:
     """Mark two strings as pluralized translations without translating them.
 
     Example usage:
@@ -249,35 +167,7 @@ def _ngettext_noop(singular, plural):
     Returns:
         tuple: Original text, unchanged.
     """
-    return (singular, plural)
-
-
-def ngettext_noop(singular, plural):
-    """Mark two strings as pluralized translations without translating them.
-
-    Example usage:
-    ```python
-    CONSTANTS = [ngettext_noop('first', 'firsts'), ngettext_noop('second', 'seconds')]
-    def num_name(n):
-        return _ngettext(*CONSTANTS[n])
-    ```
-
-    Args:
-        singular (str): Singular text to translate in the future.
-        plural (str): Plural text to translate in the future.
-
-    Returns:
-        tuple: Original text, unchanged.
-
-    WARNING: This function has been deprecated. It is still available as the private
-    member `_ngettext_noop`.
-    """
-    warnings.warn(
-        "`ngettext_noop` has been deprecated. "
-        "It is still available as the private member `_ngettext_noop`.",
-        DeprecationWarning,
-    )
-    return _ngettext_noop(singular, plural)
+    return singular, plural
 
 
 def thousands_separator() -> str:
@@ -291,3 +181,16 @@ def thousands_separator() -> str:
     except (AttributeError, KeyError):
         sep = ","
     return sep
+
+
+def decimal_separator() -> str:
+    """Return the decimal separator for a locale, default to dot.
+
+    Returns:
+         str: Decimal separator.
+    """
+    try:
+        sep = _DECIMAL_SEPARATOR[_CURRENT.locale]
+    except (AttributeError, KeyError):
+        sep = "."
+    return sep
