@@ -36,6 +36,9 @@ class FakeDate:
     def __init__(self, year: int, month: int, day: int) -> None:
         self.year, self.month, self.day = year, month, day
 
+    def __str__(self) -> str:
+        return f"{self.year}-{self.month}-{self.day}"
+
 
 VALUE_ERROR_TEST = FakeDate(290149024, 2, 2)
 OVERFLOW_ERROR_TEST = FakeDate(120390192341, 2, 2)
@@ -157,6 +160,8 @@ def test_naturaldelta(test_input: int | dt.timedelta, expected: str) -> None:
         # regression tests for bugs in post-release humanize
         (NOW + dt.timedelta(days=10000), "27 years from now"),
         (NOW - dt.timedelta(days=365 + 35), "1 year, 1 month ago"),
+        (dt.timedelta(days=-10000), "27 years from now"),
+        (dt.timedelta(days=365 + 35), "1 year, 1 month ago"),
         (23.5, "23 seconds ago"),
         (30, "30 seconds ago"),
         (NOW - dt.timedelta(days=365 * 2 + 65), "2 years ago"),
@@ -200,6 +205,9 @@ def nt_nomonths(d: dt.datetime) -> str:
         # regression tests for bugs in post-release humanize
         (NOW + dt.timedelta(days=10000), "27 years from now"),
         (NOW - dt.timedelta(days=365 + 35), "1 year, 35 days ago"),
+        (dt.timedelta(days=-10000), "27 years from now"),
+        (dt.timedelta(days=365 + 35), "1 year, 35 days ago"),
+        (23.5, "23 seconds ago"),
         (30, "30 seconds ago"),
         (NOW - dt.timedelta(days=365 * 2 + 65), "2 years ago"),
         (NOW - dt.timedelta(days=365 + 4), "1 year, 4 days ago"),
@@ -624,6 +632,8 @@ def test_precisedelta_suppress_units(
 
 
 def test_precisedelta_bogus_call() -> None:
+    assert humanize.precisedelta(None) == "None"
+
     with pytest.raises(ValueError):
         humanize.precisedelta(1, minimum_unit="years", suppress=["years"])
 
@@ -635,7 +645,6 @@ def test_time_unit() -> None:
     years, minutes = time.Unit["YEARS"], time.Unit["MINUTES"]
     assert minutes < years
     assert years > minutes
-    assert minutes == minutes
 
     with pytest.raises(TypeError):
         _ = years < "foo"
